@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2019 Canonical, Ltd.
+ * Copyright (C) 2013-2020 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -90,7 +90,11 @@ char *get_pid_cmdline(const pid_t pid)
 			*ptr = '\0';
 	}
 
-	return strdup(basename(buffer));
+	ptr = basename(buffer);
+	if (ptr)
+		return strdup(ptr);
+
+	return strdup(buffer);
 }
 
 /*
